
# THIS FILE IS GENERATED FROM syned SETUP.PY
short_version = '1.0.23'
version = '1.0.23'
full_version = '1.0.23.dev0+59e8e37'
git_revision = '59e8e37a9a54cfe704f929f117145ac2fc498c76'
release = False

if not release:
    version = full_version
    short_version += ".dev"
